summaryrefslogtreecommitdiffstats
path: root/src/pinyin.h
diff options
context:
space:
mode:
authorPeng Wu <alexepico@gmail.com>2015-10-16 13:18:14 +0800
committerPeng Wu <alexepico@gmail.com>2015-10-16 13:18:14 +0800
commit5c07a9c2ba8e12eadffa0f2c569334947193ca91 (patch)
tree570a5625ce5aca32ae2ae5b66776efdcbc4c8995 /src/pinyin.h
parent4f7407ea0b6e3611f9f177dfe1d179f287553a89 (diff)
downloadlibpinyin-5c07a9c2ba8e12eadffa0f2c569334947193ca91.tar.gz
libpinyin-5c07a9c2ba8e12eadffa0f2c569334947193ca91.tar.xz
libpinyin-5c07a9c2ba8e12eadffa0f2c569334947193ca91.zip
rename pinyin_get_chewing_string to pinyin_get_zhuyin_string
Diffstat (limited to 'src/pinyin.h')
-rw-r--r--src/pinyin.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/pinyin.h b/src/pinyin.h
index 210e9e0..95c7499 100644
--- a/src/pinyin.h
+++ b/src/pinyin.h
@@ -562,18 +562,18 @@ bool pinyin_train(pinyin_instance_t * instance);
bool pinyin_reset(pinyin_instance_t * instance);
/**
- * pinyin_get_chewing_string:
+ * pinyin_get_zhuyin_string:
* @instance: the pinyin instance.
* @key: the chewing key.
* @utf8_str: the chewing string.
* @returns: whether the get operation is successful.
*
* Get the chewing string of the key.
*
*/
-bool pinyin_get_chewing_string(pinyin_instance_t * instance,
- ChewingKey * key,
- gchar ** utf8_str);
+bool pinyin_get_zhuyin_string(pinyin_instance_t * instance,
+ ChewingKey * key,
+ gchar ** utf8_str);
/**
* pinyin_get_pinyin_string:
@@ -562,18 +562,18 @@ bool pinyin_train(pinyin_instance_t * instance);
* @instance: the pinyin instance.
* @key: the chewing key.
- * @utf8_str: the chewing string.
+ * @utf8_str: the zhuyin string.
* @returns: whether the get operation is successful.
*
@@ -562,18 +562,18 @@ bool pinyin_train(pinyin_instance_t * instance);
* @returns: whether the get operation is successful.
*
- * Get the chewing string of the key.
+ * Get the zhuyin string of the key.
*
*/